{% load i18n %}
{% if can_add_edit %}
    {% if inline_form %}
        {% include "django_library/library_form.html" %}
    {% else %}
        <a href="{% url "django_library_add_file" library.id %}?next_url={{ request.path|urlencode }}">{% trans "Add" %}</a>
    {% endif %}
{% endif %}
{% include "django_library/library_listing.html" %}